@@ -6,7 +6,7 @@
 
 #include <string.h>
 
-#include <arc/client/ExecutionTarget.h>
+#include <arc/compute/ExecutionTarget.h>
 
 #include "BenchmarkBrokerPlugin.h"
 
@@ -22,6 +22,7 @@ namespace Arc {
   }
 
   bool BenchmarkBrokerPlugin::match(const ExecutionTarget& et) const {
+    if(!BrokerPlugin::match(et)) return false;
     return et.Benchmarks->find(benchmark) != et.Benchmarks->end();
   }
 } // namespace Arc
