@@ -1,3 +1,7 @@
+#include <unistd.h>
+
+#include <arc/ArcVersion.h>
+#include <arc/GUID.h>
 #include <arc/communication/ClientInterface.h>
 #include <arc/message/MCC.h>
 #include <arc/message/PayloadRaw.h>
@@ -111,6 +115,27 @@ namespace ArcDMCRucio {
       rucio_auth_url = "https://voatlasrucio-auth-prod.cern.ch/auth/x509_proxy";
     }
     auth_url = URL(rucio_auth_url);
+
+    // Extract scope and filename
+    std::list<std::string> scopename;
+    tokenize(url.Path(), scopename, "/");
+    if (scopename.size() < 3) {
+      logger.msg(WARNING, "Strange path in Rucio URL: %s", url.str());
+    } else {
+      name = scopename.back();
+      scopename.pop_back();
+      scope = scopename.back();
+    }
+
+    // Hostname (for traces)
+    char host[256];
+    if (gethostname(host, sizeof(host)) != 0) {
+      logger.msg(WARNING, "Cannot determine hostname from gethostname()");
+    } else {
+      host[sizeof(host)-1] = 0;
+      hostname = host;
+    }
+
   }
 
   DataPointRucio::~DataPointRucio() {}
@@ -152,6 +177,24 @@ namespace ArcDMCRucio {
     std::string content;
     r = queryRucio(content, token);
     if (!r) return r;
+
+    // Query parent dataset for traces
+    std::string oldpath(url.Path());
+    url.ChangePath(std::string("/dids/"+scope+"/"+name+"/parents"));
+    std::string parentscontent;
+    r = queryRucio(parentscontent, token);
+    url.ChangePath(oldpath);
+
+    // If it fails log a warning but continue
+    if (!r) {
+      logger.msg(WARNING, "Failed to query parent DIDs: %s", std::string(r));
+    } else {
+      // Take first dataset returned
+      parentscontent = parentscontent.substr(0, parentscontent.find('\n'));
+      r = parseDIDs(parentscontent);
+      if (!r) logger.msg(WARNING, "Failed to parse Rucio info: %s", std::string(r));
+    }
+
     if (!osresolve) {
       return parseLocations(content);
     }
@@ -258,6 +301,10 @@ namespace ArcDMCRucio {
     return DataStatus(DataStatus::UnregisterError, ENOTSUP, "Deleting from Rucio is not supported");
   }
 
+  DataStatus DataPointRucio::Finalise(const std::string& error_msg, const std::string& dn) {
+    return sendTrace(error_msg, dn);
+  }
+
   DataStatus DataPointRucio::List(std::list<FileInfo>& files, DataPoint::DataPointInfoType verb) {
     return DataStatus(DataStatus::ListError, ENOTSUP, "Listing in Rucio is not supported");
   }
@@ -291,9 +338,9 @@ namespace ArcDMCRucio {
 
     HTTPClientInfo transfer_info;
     PayloadRaw request;
-    PayloadRawInterface *response = NULL;
+    AutoPointer<PayloadRawInterface> response;
 
-    MCC_Status r = client.process(attrs, &request, &transfer_info, &response);
+    MCC_Status r = client.process(attrs, &request, &transfer_info, response.ForAssign());
 
     if (!r) {
       return DataStatus(DataStatus::ReadResolveError, "Failed to contact auth server: " + r.getExplanation());
@@ -334,12 +381,11 @@ namespace ArcDMCRucio {
 
     HTTPClientInfo transfer_info;
     PayloadRaw request;
-    PayloadRawInterface *response = NULL;
+    AutoPointer<PayloadStreamInterface> response;
 
-    MCC_Status r = client.process(attrs, &request, &transfer_info, &response);
+    MCC_Status r = client.process(attrs, &request, &transfer_info, response.ForAssign());
 
     if (!r) {
-      delete response; response = NULL;
       return DataStatus(DataStatus::ReadResolveError, "Failed to contact server: " + r.getExplanation());
     }
     if (transfer_info.code != 200) {
@@ -350,37 +396,70 @@ namespace ArcDMCRucio {
       }
       return DataStatus(DataStatus::ReadResolveError, http2errno(transfer_info.code), "HTTP error when contacting server: " + errormsg);
     }
-    PayloadStreamInterface* instream = NULL;
-    try {
-      instream = dynamic_cast<PayloadStreamInterface*>(dynamic_cast<MessagePayload*>(response));
-    } catch(std::exception& e) {
-      delete response; response = NULL;
-      return DataStatus(DataStatus::ReadResolveError, "Unexpected response from server");
-    }
-    if (!instream) {
-      delete response; response = NULL;
+    if (!response) {
       return DataStatus(DataStatus::ReadResolveError, "Unexpected response from server");
     }
 
     std::string buf;
-    while (instream->Get(buf)) content += buf;
+    while (response->Get(buf)) content += buf;
     logger.msg(DEBUG, "Rucio returned %s", content);
+    return DataStatus::Success;
+  }
+
+  DataStatus DataPointRucio::postTraces(const char* data) const {
+
+    MCCConfig cfg;
+    cfg.AddCredential(usercfg.CredentialString());
+    cfg.AddCADir(usercfg.CACertificatesDirectory());
+    // Switch to correct URL
+    URL rucio_url(url);
+    rucio_url.ChangeProtocol(url.Port() == 80 ? "http" : "https");
+    if (rucio_url.Port() == -1) {
+      rucio_url.ChangePort(url.Protocol() == "http" ? 80 : 443);
+    }
+    rucio_url.ChangePath("/traces/");
+    ClientHTTP client(cfg, rucio_url, usercfg.Timeout());
+
+    std::multimap<std::string, std::string> attrmap;
+    std::string method("POST");
+    attrmap.insert(std::pair<std::string, std::string>("Content-type", "application/json"));
+    ClientHTTPAttributes attrs(method, rucio_url.Path(), attrmap);
+
+    HTTPClientInfo transfer_info;
+    PayloadRaw request;
+    request.Insert(data);
+    PayloadRawInterface *response = NULL;
+
+    MCC_Status r = client.process(attrs, &request, &transfer_info, &response);
+
     delete response; response = NULL;
+    if (!r) {
+      return DataStatus(DataStatus::GenericError, "Failed to contact server: " + r.getExplanation());
+    }
+    if (transfer_info.code != 200 && transfer_info.code != 201) {
+      return DataStatus(DataStatus::GenericError,
+                        http2errno(transfer_info.code),
+                        "HTTP error when contacting server: " + transfer_info.reason);
+    }
     return DataStatus::Success;
   }
 
   DataStatus DataPointRucio::parseLocations(const std::string& content) {
 
     // parse JSON:
-    // {"adler32": "ffa2c799",
-    //  "name": "EVNT.545023._000082.pool.root.1",
-    //  "replicas": [],
-    //  "rses": {"LRZ-LMU_DATADISK": ["srm://lcg-lrz-srm.grid.lrz.de:8443/srm/managerv2?SFN=/pnfs/lrz-muenchen.de/data/atlas/dq2/atlasdatadisk/rucio/mc11_7TeV/6c/13/EVNT.545023._000082.pool.root.1"],
-    //           "INFN-FRASCATI_DATADISK": ["srm://atlasse.lnf.infn.it:8446/srm/managerv2?SFN=/dpm/lnf.infn.it/home/atlas/atlasdatadisk/rucio/mc11_7TeV/6c/13/EVNT.545023._000082.pool.root.1"],
-    //           "TAIWAN-LCG2_DATADISK": ["srm://f-dpm001.grid.sinica.edu.tw:8446/srm/managerv2?SFN=/dpm/grid.sinica.edu.tw/home/atlas/atlasdatadisk/rucio/mc11_7TeV/6c/13/EVNT.545023._000082.pool.root.1"]},
-    //  "bytes": 69234676,
-    //  "space_token": "ATLASDATADISK",
-    //  "scope": "mc11_7TeV",
+    // {"adler32": "e2e05678",
+    //  "name": "TXT.11804243._000002.tar.gz.1",
+    //  "pfns": {"root://lapp-se01.in2p3.fr:1094//dpm/in2p3.fr/home/atlas/atlasdatadisk/rucio/mc15_13TeV/33/ce/TXT.11804243._000002.tar.gz.1":
+    //            {"rse_id": "8ccb5ac1405f4ce1b9449b7dc686b544",
+    //             "rse": "IN2P3-LAPP_DATADISK",
+    //             "type": "DISK",
+    //             "volatile": false,
+    //             "domain": "wan",
+    //             "priority": 1,
+    //             "client_extract": false},
+    //            ... },
+    //  "bytes": 162088,
+    //  "scope": "mc15_13TeV",
     //  "md5": null}
 
     if (content.empty()) {
@@ -388,28 +467,24 @@ namespace ArcDMCRucio {
       return DataStatus(DataStatus::ReadResolveError, ENOENT);
     }
 
-    cJSON *root = cJSON_Parse(content.c_str());
+    AutoPointer<cJSON> root(cJSON_Parse(content.c_str()), &cJSON_Delete);
     if (!root) {
       logger.msg(ERROR, "Failed to parse Rucio response: %s", content);
-      cJSON_Delete(root);
       return DataStatus(DataStatus::ReadResolveError, EARCRESINVAL, "Failed to parse Rucio response");
     }
-    cJSON *name = cJSON_GetObjectItem(root, "name");
+    cJSON *name = cJSON_GetObjectItem(root.Ptr(), "name");
     if (!name || name->type != cJSON_String || !name->valuestring) {
       logger.msg(ERROR, "Filename not returned in Rucio response: %s", content);
-      cJSON_Delete(root);
       return DataStatus(DataStatus::ReadResolveError, EARCRESINVAL, "Failed to parse Rucio response");
     }
     std::string filename(name->valuestring);
     if (filename != url.Path().substr(url.Path().rfind('/')+1)) {
       logger.msg(ERROR, "Unexpected name returned in Rucio response: %s", content);
-      cJSON_Delete(root);
       return DataStatus(DataStatus::ReadResolveError, EARCRESINVAL, "Failed to parse Rucio response");
     }
-    cJSON *pfns = cJSON_GetObjectItem(root, "pfns");
+    cJSON *pfns = cJSON_GetObjectItem(root.Ptr(), "pfns");
     if (!pfns) {
       logger.msg(ERROR, "No pfns returned in Rucio response: %s", content);
-      cJSON_Delete(root);
       return DataStatus(DataStatus::ReadResolveError, EARCRESINVAL, "Failed to parse Rucio response");
     }
     cJSON *pfn = pfns->child;
@@ -438,25 +513,30 @@ namespace ArcDMCRucio {
                opt != url.Options().end(); opt++)
             loc.AddOption(opt->first, opt->second, false);
           AddLocation(loc, loc.ConnectionURL());
+          cJSON *rse = cJSON_GetObjectItem(pfn, "rse");
+          if (!rse || rse->type != cJSON_String || !rse->valuestring) {
+            logger.msg(WARNING, "Error extracting RSE for %s", loc.str());
+          } else {
+            rse_map.insert(std::pair<std::string, std::string>(loc.str(), rse->valuestring));
+          }
         }
       }
       pfn = pfn->next;
     }
-    cJSON *fsize = cJSON_GetObjectItem(root, "bytes");
+    cJSON *fsize = cJSON_GetObjectItem(root.Ptr(), "bytes");
     if (!fsize || fsize->type == cJSON_NULL) {
       logger.msg(WARNING, "No filesize information returned in Rucio response for %s", filename);
     } else {
       SetSize((unsigned long long int)fsize->valuedouble);
       logger.msg(DEBUG, "%s: size %llu", filename, GetSize());
     }
-    cJSON *csum = cJSON_GetObjectItem(root, "adler32");
+    cJSON *csum = cJSON_GetObjectItem(root.Ptr(), "adler32");
     if (!csum || csum->type != cJSON_String || !csum->valuestring) {
       logger.msg(WARNING, "No checksum information returned in Rucio response for %s", filename);
     } else {
       SetCheckSum(std::string("adler32:") + std::string(csum->valuestring));
       logger.msg(DEBUG, "%s: checksum %s", filename, GetCheckSum());
     }
-    cJSON_Delete(root);
 
     if (!HaveLocations()) {
       logger.msg(ERROR, "No locations found for %s", url.str());
@@ -465,9 +545,109 @@ namespace ArcDMCRucio {
     return DataStatus::Success;
   }
 
+
+  DataStatus DataPointRucio::parseDIDs(const std::string& content) {
+
+    // parse JSON:
+    // {"name": "TXT.11804243._000002.tar.gz.1",
+    //  "scope": "mc15_13TeV",
+    //  "type": "DATASET"}
+
+    if (content.empty()) {
+      // empty response means no such file
+      return DataStatus(DataStatus::ReadResolveError, ENOENT);
+    }
+
+    AutoPointer<cJSON> root(cJSON_Parse(content.c_str()), &cJSON_Delete);
+    if (!root) {
+      logger.msg(ERROR, "Failed to parse Rucio response: %s", content);
+      return DataStatus(DataStatus::ReadResolveError, EARCRESINVAL, "Failed to parse Rucio response");
+    }
+    cJSON *dname = cJSON_GetObjectItem(root.Ptr(), "name");
+    if (!dname || dname->type != cJSON_String || !dname->valuestring) {
+      logger.msg(ERROR, "Filename not returned in Rucio response: %s", content);
+      return DataStatus(DataStatus::ReadResolveError, EARCRESINVAL, "Failed to parse Rucio response");
+    }
+
+    dataset = dname->valuestring;
+    logger.msg(VERBOSE, "Parent dataset: %s", dataset);
+    return DataStatus::Success;
+  }
+
+
+  DataStatus DataPointRucio::sendTrace(const std::string& error_msg, const std::string& dn) {
+    // Construct info
+    // UUID
+    std::string uuid = UUID();
+
+    // Filesize
+    unsigned long long filesize(size);
+
+    // Timestamp
+    time_t timeStart(Time().GetTime());
+
+    // User DN
+    std::string usrdn(dn);
+
+    // RSE
+    std::string rse = rse_map[CurrentLocation().str()];
+    if (rse.empty()) {
+      logger.msg(WARNING, "Could not find matching RSE to %s", CurrentLocation().str());
+      return DataStatus(DataStatus::GenericError, "Could not find matching RSE to current location");
+    }
+
+    // Protocol
+    std::string protocol(CurrentLocation().Protocol());
+
+    // Event type - no easy way to split production/analysis
+    std::string eventType("get_sm");
+
+    // Event sender
+    std::string eventVersion(std::string("ARC-") + std::string(ARC_VERSION));
+
+    // State and error message
+    std::string clientState("DONE");
+    std::string stateReason("OK");
+    if (!error_msg.empty()) {
+      clientState = "ServiceUnavailable";
+      stateReason = error_msg;
+    }
+
+    // Construct json
+    cJSON *root = cJSON_CreateObject();
+    cJSON_AddStringToObject(root, "type", "rucio-trace");
+    cJSON_AddStringToObject(root, "uuid", uuid.c_str());
+    cJSON_AddStringToObject(root, "scope", scope.c_str());
+    cJSON_AddStringToObject(root, "filename", name.c_str());
+    cJSON_AddStringToObject(root, "dataset", dataset.c_str());
+    cJSON_AddNumberToObject(root, "filesize", filesize);
+    cJSON_AddNumberToObject(root, "timeStart", timeStart);
+    cJSON_AddStringToObject(root, "usrdn", usrdn.c_str());
+    cJSON_AddStringToObject(root, "localSite", rse.c_str());
+    cJSON_AddStringToObject(root, "remoteSite", rse.c_str());
+    cJSON_AddStringToObject(root, "hostname", hostname.c_str());
+    cJSON_AddStringToObject(root, "protocol", protocol.c_str());
+    cJSON_AddStringToObject(root, "eventType", eventType.c_str());
+    cJSON_AddStringToObject(root, "eventVersion", eventVersion.c_str());
+    cJSON_AddStringToObject(root, "clientState", clientState.c_str());
+    cJSON_AddStringToObject(root, "stateReason", stateReason.c_str());
+    char *traces = cJSON_Print(root);
+
+    // Send the trace
+    logger.msg(DEBUG, "Sending Rucio trace: %s", traces);
+    DataStatus res = postTraces(traces);
+    if (!res.Passed()) {
+      logger.msg(WARNING, "Failed to send traces to Rucio: %s", std::string(res));
+    }
+
+    free(traces);
+    cJSON_Delete(root);
+    return DataStatus::Success;
+  }
+
 } // namespace ArcDMCRucio
 
 extern Arc::PluginDescriptor const ARC_PLUGINS_TABLE_NAME[] = {
-  { "rucio", "HED:DMC", "ATLAS Data Management System", 0, &ArcDMCRucio::DataPointRucio::Instance },
+  { "rucio", "HED:DMC", "Rucio Data Management System", 0, &ArcDMCRucio::DataPointRucio::Instance },
   { NULL, NULL, NULL, 0, NULL }
 };
