@@ -4,11 +4,6 @@
 #include <iostream>
 #include <string>
 
-#ifdef WIN32
-#include <arc/win32.h>
-#endif
-
-
 #include <globus_common.h>
 
 namespace Arc {
