@@ -20,6 +20,9 @@ script=$1
 shift
 . $script
 }
+# Record job start timestamp
+ACCOUNTING_STARTTIME=`date +"%s"`
+# Select accounting method
 echo "Detecting resource accounting method available for the job." 1>&2
 JOB_ACCOUNTING=""
 # Try to use cgroups first
@@ -301,6 +304,13 @@ fi
 # Record WN instance tag if defined
 [ -n "${ACCOUNTING_WN_INSTANCE}" ] && echo "wninstance=${ACCOUNTING_WN_INSTANCE}" >> "$RUNTIME_JOB_DIAG"
 
+# Record execution clock times
+ACCOUNTING_ENDTIME=`date +"%s"`
+# Mds date format (YYYYMMDDHHMMSSZ)
+echo "LRMSStartTime=`date -d "1970-01-01 UTC ${ACCOUNTING_STARTTIME} seconds" +"%Y%m%d%H%M%SZ"`" >> "$RUNTIME_JOB_DIAG"
+echo "LRMSEndTime=`date -d "1970-01-01 UTC ${ACCOUNTING_ENDTIME} seconds" +"%Y%m%d%H%M%SZ"`" >> "$RUNTIME_JOB_DIAG"
+echo "walltime=$(( ACCOUNTING_ENDTIME - ACCOUNTING_STARTTIME ))" >> "$RUNTIME_JOB_DIAG"
+
 # Add exit code to the accounting information and exit the job script
 echo "exitcode=$RESULT" >> "$RUNTIME_JOB_DIAG"
 exit $RESULT
