@@ -451,7 +451,7 @@ class SGASSender(object):
                 self.logger.error('Failed to POST records to SGAS server %s. Error code %s returned: %s',
                                   self.conf['targethost'], str(resp.status), resp.reason)
                 # parse error from SGAS Traceback in returned HTML
-                for line in resp.read().split('\n'):
+                for line in resp.read().decode('utf-8').split('\n'):
                     if line.startswith('<p class="error"'):
                         errstr = line.replace('<p class="error">&lt;class', '').replace('&gt;', '').replace('</p>', '')
                         self.logger.error('SGAS returned the following error description:%s', errstr)
@@ -560,10 +560,18 @@ class APELAMSDirectSender(object):
         )
         utcnow = datetime.datetime.utcnow().strftime("%Y%m%d%H%M%S")
         empaid = "{0}/{1}".format(utcnow[:8], utcnow)
-        msg = {
-            'attributes': {'empaid': empaid},
-            'data': base64.encodestring(self._msg_sign(data)).decode('utf-8')
-        }
+        try:
+            """ python3 """
+            msg = {
+                'attributes': {'empaid': empaid},
+                'data': base64.b64encode(bytes(self._msg_sign(data),'utf-8')).decode('utf-8')
+            }
+        except:
+            """ python2.7 """
+            msg = {
+                'attributes': {'empaid': empaid},
+                'data': base64.encodestring(self._msg_sign(data)).decode('utf-8')
+            }
 
         conn = HTTPSClientAuthConnection(
             host=self.conf['targethost'],
